@@ -557,9 +557,6 @@ static void
 Set_Orig_and_Size( NEW_WIN_CONTEXT *wc, MOL_SURF *m, struct Togl *togl )
 {
   int i;
-  double aspect;
-
-  aspect = wc->VPf.width / wc->VPf.height;
     
   if ( m->fs.celltype == XCR_BZ ) {
     for (i=0; i<3; i++)
