@@ -211,7 +211,7 @@ ReadStructFile(FILE *fp, char *file, int format, int mode)
 
   ss.minX = ss.maxX = mx;
   ss.minY = ss.maxY = my;
-  ss.maxZ = ss.maxZ = mz;
+  ss.minZ = ss.maxZ = mz;
   atm.natomkind = 0;
   
   for(i = 1; i <= natoms; i++) {
@@ -314,7 +314,6 @@ ReadStructFile(FILE *fp, char *file, int format, int mode)
 void
 MakeBonds(void)
 {
-  int sizeIA, sizeDA;
   int i, j, k, max_ibn, *ibn;
   int numb = 0; /* numb == seq. number of bond; 
 		   0 because we increase ++numb, before usage */
@@ -337,10 +336,6 @@ MakeBonds(void)
 
   max_ibn = nsplit * MAX_BONDS;
 
-  /* NOW ALLOCATE A MEMORY */
-  sizeDA = sizeof(double) * (nbonds + 1);
-  sizeIA = sizeof(int) * (nbonds + 1);
-
   {
     int nb1 = nbonds+1;
     natbond = (int *) calloc(nb1, sizeof(int));
@@ -540,7 +535,7 @@ ReadXSF(FILE *fp)
   int n, idummy;
   long int atompos = 0;  /* position where atom coor starts in the file */
   long int framepos = 0; /* position where frame coor starts in the file */
-  int linesize=256;
+  size_t linesize=256;
   static char *line = 0;
 
   if (line==0) {
@@ -1064,7 +1059,8 @@ ReadVec(FILE *fp, double vec[][4])
 static int
 ReadCoor( FILE *fp, int natr, int ncell, const int celltype )
 {
-  int i, n, size, linesize=256;
+  int i, n, size;
+  size_t linesize=256;
   double (*coor)[3], (*forc)[3];
   int  *atn;
   static char *line = 0;
@@ -1134,7 +1130,7 @@ ReadAtoms( FILE *fp , long int atompos )
   double dis;
   double *xat1, *yat1, *zat1, (*fv1)[3];
   int *nat1, *flag1;
-  int linesize = 256;
+  size_t linesize = 256;
   static char *line = 0;
 
   if (line == 0) {
