@@ -93,8 +93,6 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 						   string is 512 characters */
 
   boolean  rectangular  = 0;
-  boolean  size_is      = 0;
-  boolean  rot_is       = 0;
   boolean  paralle2D_is = 0;
   boolean  center2D_is  = 0;
   boolean  cell3D_is    = 0;
@@ -189,14 +187,12 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 	  sprintf(interp->result, "wanted double, but got %s", argv[i+1]);
 	  return TCL_ERROR;		  
 	}
-	size_is = 1;
       }
       else if ( strncmp(argv[i], "-rot", 4) == 0 ) {
 	if ( Tcl_GetDouble( interp, argv[i+1], &rot ) == TCL_ERROR ) {
 	  sprintf(interp->result, "wanted double, but got %s", argv[i+1]);
 	  return TCL_ERROR;
 	}
-	rot_is = 1;
       }
       else {
 	sprintf(interp->result, "unknown option %s for xc_isospacesel <mesaWin> center2D, should be one of -center, -normal, -size or -rotate", argv[i]);
@@ -390,7 +386,6 @@ Paralle2D( GetComOption points, GetComOption mar, boolean rectangular )
   int ii[2];
   float det, k;
   float *p[4], bc[3], ba[3], nml[3], bc_nml[3], d[2][3];
-  float bc_s, ba_s;
 
   p[0] = points.vec;
   p[1] = points.vec + 3;
@@ -400,8 +395,6 @@ Paralle2D( GetComOption points, GetComOption mar, boolean rectangular )
     bc[i] = points.vec[6+i] - points.vec[3+i];
     ba[i] = points.vec[i]   - points.vec[3+i];
   }
-  bc_s = distfv( bc );
-  ba_s = distfv( ba );
 
   VecProduct3f( bc, ba, nml );
   if ( distfv( nml ) < 1.0e-6 ) {
@@ -487,16 +480,6 @@ Paralle2D( GetComOption points, GetComOption mar, boolean rectangular )
     p[2][i] +=  mar.vec[1] * bc[i] - mar.vec[3] * ba[i];
     p[3][i] +=  mar.vec[1] * bc[i] + mar.vec[2] * ba[i];
   }
-  /* this is OLD (margins in ANGS units */
-/*    for (i=0; i<3; i++) { */
-/*      if ( !rectangular ) spV = fabs(bc_nml[i] * ba[i]) * ba[i]/ba_s*ba_s; */
-/*      else spV = bc_nml[i]; */
-/*      bcn = bc[i] / bc_s; */
-/*      p[0][i] += -mar.vec[0] * bcn + mar.vec[2] * spV; */
-/*      p[1][i] += -mar.vec[0] * bcn - mar.vec[3] * spV; */
-/*      p[2][i] +=  mar.vec[1] * bcn - mar.vec[3] * spV; */
-/*      p[3][i] +=  mar.vec[1] * bcn + mar.vec[2] * spV; */
-/*    } */
 
   /* assign parallelogram's normal */
   for (i=0; i<3; i++) {
